Type Alias lua_Integer
Source pub type lua_Integer = int64_t;
A Lua integer, usually equivalent to i64.
Converts the value on top of the stack of a Lua state to a value of type
Option<Self>.
Pushes a value of type Self onto the stack of a Lua state.